@@ -1,3 +1,4 @@
+from typing import Any
 from .private.Keysight_344xxA_submodules import _Keysight_344xxA
 
 
@@ -5,6 +6,6 @@ class Keysight_34470A(_Keysight_344xxA):
     """
     This is the qcodes driver for the Keysight 34470A Multimeter
     """
-    def __init__(self, name, address, silent=False,
-                 **kwargs):
+    def __init__(self, name: str, address: str, silent: bool = False,
+                 **kwargs: Any):
         super().__init__(name, address, silent, **kwargs)
